==> nomachine-8.11.3-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Exception/MaximunNumberSessionsForUser.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Exception::MaximunNumberSessionsForUser::BEGIN{package 
Exception::MaximunNumberSessionsForUser;no warnings;require base;do{
"\x62\x61\x73\x65"->import (
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x42\x61\x73\x65")};}sub 
Exception::MaximunNumberSessionsForUser::BEGIN{package 
Exception::MaximunNumberSessionsForUser;no warnings;require overload;do{
"\x6f\x76\x65\x72\x6c\x6f\x61\x64"->import ("\x22\x22",
"\x73\x74\x72\x69\x6e\x67\x69\x66\x79")};}sub 
Exception::MaximunNumberSessionsForUser::notify{package 
Exception::MaximunNumberSessionsForUser;no warnings;(my $self=shift (@_));(my $ref_parameters
=$$self{"\x72\x65\x66\x50\x61\x72\x61\x6d\x65\x74\x65\x72\x73"});
NXMsg::register_error ((""),
"\x65\x4d\x61\x78\x69\x6d\x75\x6d\x4e\x75\x6d\x62\x65\x72\x53\x65\x73\x73\x69\x6f\x6e\x73\x46\x6f\x72\x55\x73\x65\x72"
,(0x1226+ 5257-0x2495));NXMsg::error (
"\x65\x4d\x61\x78\x69\x6d\x75\x6d\x4e\x75\x6d\x62\x65\x72\x53\x65\x73\x73\x69\x6f\x6e\x73\x46\x6f\x72\x55\x73\x65\x72"
,"\x67\x65\x6e\x65\x72\x61\x6c",@$ref_parameters);}package 
Exception::MaximunNumberSessionsForUser;no warnings;"\x3f\x3f\x3f";

==> nomachine-8.12.12-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Exception/MaximunNumberSessionsForUser.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Exception::MaximunNumberSessionsForUser::BEGIN{package 
Exception::MaximunNumberSessionsForUser;no warnings;require base;do{
"\x62\x61\x73\x65"->import (
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x42\x61\x73\x65")};}sub 
Exception::MaximunNumberSessionsForUser::BEGIN{package 
Exception::MaximunNumberSessionsForUser;no warnings;require overload;do{
"\x6f\x76\x65\x72\x6c\x6f\x61\x64"->import ("\x22\x22",
"\x73\x74\x72\x69\x6e\x67\x69\x66\x79")};}sub 
Exception::MaximunNumberSessionsForUser::notify{package 
Exception::MaximunNumberSessionsForUser;no warnings;(my $self=shift (@_));(my $ref_parameters
=$$self{"\x72\x65\x66\x50\x61\x72\x61\x6d\x65\x74\x65\x72\x73"});
NXMsg::register_error ((""),
"\x65\x4d\x61\x78\x69\x6d\x75\x6d\x4e\x75\x6d\x62\x65\x72\x53\x65\x73\x73\x69\x6f\x6e\x73\x46\x6f\x72\x55\x73\x65\x72"
,(0x0d33+ 4388-0x1c3d));NXMsg::error (
"\x65\x4d\x61\x78\x69\x6d\x75\x6d\x4e\x75\x6d\x62\x65\x72\x53\x65\x73\x73\x69\x6f\x6e\x73\x46\x6f\x72\x55\x73\x65\x72"
,"\x67\x65\x6e\x65\x72\x61\x6c",@$ref_parameters);}package 
Exception::MaximunNumberSessionsForUser;no warnings;"\x3f\x3f\x3f";
